%% 
%% This is file `dvipsone.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `tiffrules,dvipsone,pscolor,pscolorsimple,colfix,psrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{dvipsone.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@dvipsone.def\endcsname\relax\endinput\fi
\def\Ginclude@eps#1{%
\message{<#1>}%
  \raise\Gin@req@height\hbox{%
      \special{ps::[begin]
      \number\Gin@req@width\space
      \number\Gin@req@height\space
      \number\Gin@llx\space
      \number\Gin@lly\space
      \number\Gin@urx\space
      \number\Gin@ury\space startTexFig}%
    \special{ps: plotfile #1}%
    \ifGin@clip\special{ps:: doclip}\fi
    \special{ps::[end] endTexFig}%
  }%
}
\def\Ginclude@tiff#1{%
\message{<#1>}%
 \special{insertimage: #1 \number\Gin@req@width\space
     \number\Gin@req@height}%
}
\def\Raw@PS#1{\special{ps: #1}}
\def\Grot@start{%
 \special{ps: gsave currentpoint
 currentpoint translate \Grot@angle\space
 rotate neg exch neg exch translate}}
\def\Grot@end{\special{ps: currentpoint grestore moveto}}
\def\Gscale@start{\special{ps:  currentpoint currentpoint translate
  \Gscale@x\space \Gscale@y\space scale neg exch neg exch translate}}
\def\Gscale@end{\special{ps:  currentpoint currentpoint translate
  1 \Gscale@x\space div 1 \Gscale@y\space div scale
  neg exch neg exch translate}}
\def\color@arg#1{%
  \dimen@#1\p@
  \ifdim\dimen@<\z@\out@of@range
  \else\ifdim\dimen@>\p@\out@of@range
  \fi\fi}
\def\color@rgb#1{\color@@rgb#1\@@}
\def\color@@rgb#1,#2,#3\@@{%
  \color@arg{#1}%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@rgb@{ #1 #2 #3}}
\def\color@cmyk#1{\color@@cmyk#1\@@}
\def\color@@cmyk#1,#2,#3,#4\@@{%
  \color@arg{#1}%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \color@cmyk@{#1 #2 #3 #4}}
\def\definecolor@gray#1#2{%
  \color@arg{#2}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@gray@{#2}}}
\def\definecolor@rgb#1#2{\definecolor@rgb@{#1}#2\@@}
\def\definecolor@rgb@#1#2,#3,#4\@@{%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@rgb@{#2 #3 #4}}}
\def\definecolor@cmyk#1#2{\definecolor@cmyk@{#1}#2\@@}
\def\definecolor@cmyk@#1#2,#3,#4,#5\@@{%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \color@arg{#5}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@cmyk@{#2 #3 #4 #5}}}
\def\current@ps@color{\current@color}
\def\set@color{%
  \Raw@PS{\current@color}\aftergroup\reset@color}
\def\reset@color{\Raw@PS{\current@color}}
\def\set@page@color{%
  \write\sixt@@n{background color ignored: \current@color}}
\def\color@named#1{%
  \edef\@tempa{\noexpand\color@rgb{\csname named@#1\endcsname}}%
  \@tempa}
\def\color@cmyk@#1{%
  \edef\current@color{#1 setcmykcolor}%
  \set@color}
\def\color@rgb@#1{%
  \edef\current@color{#1 setrgbcolor}%
  \set@color}
\def\named@Black{0,0,0}
\def\named@White{1,1,1}
\def\named@Red  {1,0,0}
\def\named@Green{0,1,0}
\def\named@Blue {0,0,1}
\def\color@gray#1{%
  \edef\current@color{#1 setgray}%
  \set@color}
\def\definecolor@named#1#2{%
  \@ifundefined{named@#1}{\typeout{WARNING cannot define colour #1}}{%
  \expandafter\def\csname\string\color @#1\endcsname{\color@named{#2}}}%
}
\def\current@color{0 setgray}
\let\@ldc@l@r\color
 \def\color{\if@inlabel\leavevmode\fi\@ldc@l@r}%
\let\@ldtextc@l@r\textcolor
 \def\textcolor{\if@inlabel\leavevmode\fi\@ldtextc@l@r}%
\let\@lduseb@x\usebox
 \def\usebox#1{\@lduseb@x{#1}\set@color}
\def\Gin@extensions{eps,ps}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@ps}#1{{eps}{ps}{#1}}
\@namedef{Gin@rule@eps}#1{{eps}{eps}{#1}}
 \@namedef{Gin@rule@tif}#1{{tiff}{}{#1}}
\endinput
%% 
%% End of file `dvipsone.def'.
