%% 
%% This is file `dvitops.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `dvitops,psrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{dvitops.def}
\ProvidesFile{dvitops.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@dvitops.def\endcsname\relax\endinput\fi
\newcount\Grot@count
\Grot@count=\@ne
\def\Grot@start{\special{dvitops: origin
    rot\the\@tempdima}%
\special{dvitops: begin rot\the\Grot@count}}%
\def\Grot@end{\special{dvitops: end}%
\special{dvitops: rotate rot\the\Grot@count \space
    \Grot@angle}%
\global\advance\Grot@count by\@ne}%
\def\Ginclude@eps#1{%
\multiply\Gin@req@width by \@m
\multiply\Gin@req@height by \@m
\ifGin@clip
  \typeout{no clipping support in dvitops}%
\fi
\special{import #1\space \Gin@req@width\space
\the\Gin@req@height\space fill}%
}
\def\Gin@extensions{eps,ps}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@ps}#1{{eps}{ps}{#1}}
\@namedef{Gin@rule@eps}#1{{eps}{eps}{#1}}
\endinput
%% 
%% End of file `dvitops.def'.
