%% 
%% This is file `dvilaser.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `dvilaser,psrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{dvilaser.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@dvilaser.def\endcsname\relax\endinput\fi
\def\Ginclude@eps#1{%
\ifGin@clip
  \typeout{no clipping support in dvilaser/ps}%
\fi
\special{ps: epsfile #1\space \the\Gin@req@width}%
}
\def\Gin@extensions{eps,ps}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@ps}#1{{eps}{ps}{#1}}
\@namedef{Gin@rule@eps}#1{{eps}{eps}{#1}}
\endinput
%% 
%% End of file `dvilaser.def'.
