%% 
%% This is file `babel.def', generated 
%% on <1994/9/8> with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% babel.dtx  (with options: `def')
%% 
%% Copyright (C) 1989-1994 by Johannes Braams 
%% All rights reserved. 
%% For additional copyright information see further down in this file. 
%% 
%% This file is part of the Babel system, release 3.4 patchlevel 1 
%% --------------------------------------------------------------- 
%% 
%% This file is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
%% 
%% IMPORTANT NOTICE: 
%% 
%% For error reports in case of UNCHANGED versions see readme file. 
%% 
%% Please do not request updates from me directly. Distribution is 
%% done through Mail-Servers and TeX organizations. 
%% 
%% You are not allowed to change this file. 
%% 
%% You are allowed to distribute this file under the condition that 
%% it is distributed together with all files mentioned in manifest.txt. 
%% 
%% If you receive only some of these files from someone, complain! 
%% 
%% You are NOT ALLOWED to distribute this file alone. You are NOT 
%% ALLOWED to take money for the distribution or use of either this 
%% file or a changed version, except for a nominal charge for copying 
%% etc. 
%%%\iffalse
%%%  @LaTeX-file{
%%%     author          = "Johannes L. Braams",
%%%     version         = "3.4d",
%%%     date            = "05 June 1994",
%%%     time            = "14:09:50 MET",
%%%     filename        = "babel.dtx",
%%%     address         = "PTT Research
%%%                        St. Paulusstraat 4
%%%                        2264 XZ Leidschendam
%%%                        The Netherlands",
%%%     telephone       = "(70) 3325051",
%%%     FAX             = "(70) 3326477",
%%%     checksum        = "49524 2026 9500 78244",
%%%     email           = "J.L.Braams@research.ptt.nl (Internet)",
%%%     codetable       = "ISO/ASCII",
%%%     keywords        = "babel",
%%%     supported       = "yes",
%%%     docstring       = "This file, babel.dtx contains the core of
%%%                        the babel system as it was described in
%%%                        TuGboat Volume 12 no 2 and Volume 14 no 1.
%%%
%%%                        The checksum field above contains a CRC-16
%%%                        checksum as the first value, followed by the
%%%                        equivalent of the standard UNIX wc (word
%%%                        count) utility output of lines, words, and
%%%                        characters.  This is produced by Robert
%%%                        Solovay's checksum utility.",
%%%      }
%%% \fi
%%
%% Copyright (C) 1989-1994 by Johannes Braams,
%%                            PTT Research Neher Laboratories
%%                            all rights reserved.
%% Please report errors to: J.L. Braams
%%                          J.L.Braams@research.ptt.nl
\ifx\ProvidesFile\undefined
  \def\ProvidesFile#1[#2 #3 #4]{\wlog{#4 #3 <#2>}}\fi
\ProvidesFile{babel.def}
                [1994/06/24 v3.4e
         Babel common definitions]
\ifx\undefined\iflanguage
  \input switch.def\relax
\fi
\let\babel@core@loaded\relax
\def\babel@add@special#1{\begingroup
    \def\do{\noexpand\do\noexpand}%
    \def\@makeother{\noexpand\@makeother\noexpand}%
    \edef\x{\endgroup
      \def\noexpand\dospecials{\dospecials\do#1}%
      \expandafter\ifx\csname @sanitize\endcsname\relax \else
        \def\noexpand\@sanitize{\@sanitize\@makeother#1}%
      \fi}%
  \x}
\def\babel@remove@special#1{\begingroup
    \def\x##1##2{\ifnum`#1=`##2\noexpand\empty
                 \else\noexpand##1\noexpand##2\fi}%
    \def\do{\x\do}%
    \def\@makeother{\x\@makeother}%
    \edef\x{\endgroup
      \def\noexpand\dospecials{\dospecials}%
      \expandafter\ifx\csname @sanitize\endcsname\relax \else
        \def\noexpand\@sanitize{\@sanitize}%
      \fi}%
  \x}
\def\babel@beginsave{\babel@savecnt\z@}
\newcount\babel@savecnt
\babel@beginsave
\def\babel@save#1{%
  \expandafter\let\csname babel@\number\babel@savecnt\endcsname #1\relax
  \begingroup
    \toks@\expandafter{\originalTeX \let#1=}%
    \edef\x{\endgroup
      \def\noexpand\originalTeX{\the\toks@ \expandafter\noexpand
         \csname babel@\number\babel@savecnt\endcsname\relax}}%
  \x
  \advance\babel@savecnt\@ne}
\def\babel@savevariable#1{\begingroup
    \toks@\expandafter{\originalTeX #1=}%
    \edef\x{\endgroup
      \def\noexpand\originalTeX{\the\toks@ \the#1\relax}}%
  \x}
\def\addto#1#2{%
  \ifx#1\undefined
    \def#1{#2}
  \else
  {\toks@\expandafter{#1#2}%
   \xdef#1{\the\toks@}}%
  \fi
}
\def\allowhyphens{\penalty\@M \hskip\z@skip}
\def\set@low@box#1{\setbox\tw@\hbox{,}\setbox\z@\hbox{#1}%
    \dimen\z@\ht\z@ \advance\dimen\z@ -\ht\tw@%
    \setbox\z@\hbox{\lower\dimen\z@ \box\z@}\ht\z@\ht\tw@ \dp\z@\dp\tw@}
\def\save@sf@q#1{{\ifhmode
    \edef\@SF{\spacefactor\the\spacefactor}\else
    \let\@SF\empty \fi \leavevmode #1\@SF}}
{\def\format{lplain}
\ifx\fmtname\format
\else
  \def\format{LaTeX2e}
  \ifx\fmtname\format
  \else
    \aftergroup\endinput
  \fi
\fi}
\long\def\babel@sanitize@arg#1#2{\bgroup\def\@tempa{#2}%
  \expandafter\babel@strip@meaning\meaning\@tempa\relax{#1}}
\def\babel@strip@meaning#1->#2\relax#3{\egroup #3{#2}}
\let\LTX@label=\label
\def\label#1{\babel@sanitize@arg\LTX@label{#1}}
\let\LTX@newlabel=\newlabel
\def\newlabel#1#2{\babel@sanitize@arg\LTX@newlabel{#1}{#2}}
\let\LTX@ref=\ref
\def\ref#1{\babel@sanitize@arg\LTX@ref{#1}}
\let\LTX@pageref=\pageref
\def\pageref#1{\babel@sanitize@arg\LTX@pageref{#1}}
\let\LTX@@citex\@citex
\def\@citex[#1]#2{\babel@sanitize@arg{\LTX@@citex[#1]}{#2}}
\let\LTX@nocite\nocite
\def\nocite#1{\babel@sanitize@arg\LTX@nocite{#1}}
\let\LTX@bibcite\bibcite
\def\bibcite#1#2{\babel@sanitize@arg\LTX@bibcite{#1}{#2}}
\let\LTX@@bibitem\@bibitem
\def\@bibitem#1{\babel@sanitize@arg\LTX@@bibitem{#1}}
\let\LTX@@lbibitem\@lbibitem
\def\@lbibitem[#1]#2{\babel@sanitize@arg{\LTX@@lbibitem[#1]}{#2}}
\let\LTX@@testdef=\@testdef
\def\@testdef#1#2{\babel@sanitize@arg{\LTX@@testdef{#1}}{#2}}
%%\languagespecific{russian.dtx}
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\endinput
%% 
%% End of file `babel.def'.
