%% 
%% This is file `xdvi.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `xdvi')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{xdvi.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\endinput
%% 
%% End of file `xdvi.def'.
