%% 
%% This is file `dviwindo.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `dviwindo,colfix,tiffrules,dosrules,psrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{dviwindo.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@dviwindo.def\endcsname\relax\endinput\fi
\def\Ginclude@eps#1{%
\message{<#1>}%
  \raise\Gin@req@height\hbox{%
      \special{ps::[begin]
      \number\Gin@req@width\space
      \number\Gin@req@height\space
      \number\Gin@llx\space
      \number\Gin@lly\space
      \number\Gin@urx\space
      \number\Gin@ury\space startTexFig}%
    \special{ps: plotfile #1}%
    \ifGin@clip\special{ps:: doclip}\fi
    \special{ps::[end] endTexFig}%
  }%
}
\def\Ginclude@tiff#1{%
\message{<#1>}%
 \special{insertimage: #1 \number\Gin@req@width\space
     \number\Gin@req@height}%
}
\def\set@color{%
  \special{textcolor: \current@color}%
  \special{rulecolor: \current@color}%
  \aftergroup\reset@color
}
\def\reset@color{%
 \special{textcolor: \current@color}%
 \special{rulecolor: \current@color}%
}
\def\set@page@color{%
  \write\sixt@@n{background color ignored: \current@color}}
\def\color@RGB#1{\color@RGB@#1\@@}
\def\color@RGB@#1,#2,#3\@@{%
  \edef\current@color{#1 #2 #3}%
  \set@color}
\def\color@rgb@RGB#1{%
  \dimen@#1\p@
  \dimen@255\dimen@
  \@settopoint\dimen@
  \edef\@tempa{\@tempa,\strip@pt\dimen@}}
\def\color@rgb#1{\color@rgb@#1\@@}
\def\color@rgb@#1,#2,#3\@@{%
  \def\a{#1,#2,#3}
  \let\@tempa\@gobble
  \color@rgb@RGB{#1}%
  \color@rgb@RGB{#2}%
  \color@rgb@RGB{#3}%
  \expandafter\color@RGB\expandafter{\@tempa}}
\def\cmyk@rgb#1{%
  \dimen@#1\p@
  \advance\dimen@\@tempdima
  \ifdim\dimen@>\p@
    \dimen@\z@
  \else
    \advance\dimen@-\p@
    \dimen@-\dimen@
  \fi
  \edef\@tempa{\@tempa,\strip@pt\dimen@}}
\def\color@cmyk#1{\color@cmyk@#1\@@}
\def\color@cmyk@#1,#2,#3,#4\@@{%
  \@tempdima#4\p@
  \let\@tempa\@gobble
  \cmyk@rgb{#1}%
  \cmyk@rgb{#2}%
  \cmyk@rgb{#3}%
  \expandafter\color@rgb\expandafter{\@tempa}}
\def\definecolor@gray#1#2{%
  \expandafter\def\csname\string\color @#1\endcsname{\color@gray{#2}}}
\def\definecolor@RGB#1#2{%
  \expandafter\def\csname\string\color @#1\endcsname{\color@RGB{#2}}}
\def\definecolor@rgb#1#2{%
  \expandafter\def\csname\string\color @#1\endcsname{\color@rgb{#2}}}
\def\definecolor@cmyk#1#2{%
  \definecolor@cmyk@{#1}#2\@@}
\def\definecolor@cmyk@#1#2,#3,#4,#5\@@{%
  \@tempdima#5\p@
  \let\@tempa\@gobble
  \cmyk@rgb{#2}%
  \cmyk@rgb{#3}%
  \cmyk@rgb{#4}%
  \edef\@tempa{\noexpand\definecolor@rgb{#1}{\@tempa}}%
  \@tempa}
\def\current@color{0 0 0 }
\let\@ldc@l@r\color
 \def\color{\if@inlabel\leavevmode\fi\@ldc@l@r}%
\let\@ldtextc@l@r\textcolor
 \def\textcolor{\if@inlabel\leavevmode\fi\@ldtextc@l@r}%
\let\@lduseb@x\usebox
 \def\usebox#1{\@lduseb@x{#1}\set@color}
\def\Gin@extensions{eps,ps}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@ps}#1{{eps}{ps}{#1}}
\@namedef{Gin@rule@eps}#1{{eps}{eps}{#1}}
\def\Gin@extensions{eps,ps,pcx,bmp}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@pcx}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@msp}#1{{bmp}{}{#1}}
 \@namedef{Gin@rule@tif}#1{{tiff}{}{#1}}
\endinput
%% 
%% End of file `dviwindo.def'.
