%% 
%% This is file `dvips.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `dvips,pscolor,psrulesZ,dosrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{dvips.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@dvips.def\endcsname\relax\endinput\fi
\def\set@color{%
  \special{color push \current@color}\aftergroup\reset@color}
\def\reset@color{\special{color pop}}
\def\set@page@color{\special{background \current@color}}
\def\color@named#1{%
  \expandafter\ifx\csname col@#1\endcsname\color@check
    \color@named@{#1}%
  \else
    \UndefinedColor
  \fi}
\def\color@check{\color@check}
\let\col@GreenYellow\color@check
\let\col@Yellow\color@check
\let\col@Goldenrod\color@check
\let\col@Dandelion\color@check
\let\col@Apricot\color@check
\let\col@Peach\color@check
\let\col@Melon\color@check
\let\col@YellowOrange\color@check
\let\col@Orange\color@check
\let\col@BurntOrange\color@check
\let\col@Bittersweet\color@check
\let\col@RedOrange\color@check
\let\col@Mahogany\color@check
\let\col@Maroon\color@check
\let\col@BrickRed\color@check
\let\col@Red\color@check
\let\col@OrangeRed\color@check
\let\col@RubineRed\color@check
\let\col@WildStrawberry\color@check
\let\col@Salmon\color@check
\let\col@CarnationPink\color@check
\let\col@Magenta\color@check
\let\col@VioletRed\color@check
\let\col@Rhodamine\color@check
\let\col@Mulberry\color@check
\let\col@RedViolet\color@check
\let\col@Fuchsia\color@check
\let\col@Lavender\color@check
\let\col@Thistle\color@check
\let\col@Orchid\color@check
\let\col@DarkOrchid\color@check
\let\col@Purple\color@check
\let\col@Plum\color@check
\let\col@Violet\color@check
\let\col@RoyalPurple\color@check
\let\col@BlueViolet\color@check
\let\col@Periwinkle\color@check
\let\col@CadetBlue\color@check
\let\col@CornflowerBlue\color@check
\let\col@MidnightBlue\color@check
\let\col@NavyBlue\color@check
\let\col@RoyalBlue\color@check
\let\col@Blue\color@check
\let\col@Cerulean\color@check
\let\col@Cyan\color@check
\let\col@ProcessBlue\color@check
\let\col@SkyBlue\color@check
\let\col@Turquoise\color@check
\let\col@TealBlue\color@check
\let\col@Aquamarine\color@check
\let\col@BlueGreen\color@check
\let\col@Emerald\color@check
\let\col@JungleGreen\color@check
\let\col@SeaGreen\color@check
\let\col@Green\color@check
\let\col@ForestGreen\color@check
\let\col@PineGreen\color@check
\let\col@LimeGreen\color@check
\let\col@YellowGreen\color@check
\let\col@SpringGreen\color@check
\let\col@OliveGreen\color@check
\let\col@RawSienna\color@check
\let\col@Sepia\color@check
\let\col@Brown\color@check
\let\col@Tan\color@check
\let\col@Gray\color@check
\let\col@Black\color@check
\let\col@White\color@check
\def\color@@#1{%
  \def\current@color{#1}%
  \set@color}
\def\color@named@#1{%
  \def\current@ps@color{/TeXDict begin #1 end}%
  \color@@{#1}}
\def\color@gray#1{%
  \color@arg{#1}%
  \color@gray@{#1}}
\def\color@gray@#1{%
  \def\current@ps@color{#1 setgray}%
  \color@@{gray #1}}
\def\color@rgb@#1{%
  \def\current@ps@color{#1 setrgbcolor}%
  \color@@{rgb #1}}
\def\color@cmyk@#1{%
  \def\current@ps@color{#1 setcmycolor}%
  \color@@{cmyk #1}}
\def\definecolor@named#1#2{%
  \expandafter\ifx\csname col@#2\endcsname\color@check
    \expandafter\def\csname\string\color @#1\endcsname{%
                            \color@named@{#2}}%
  \else
    \UndefinedColor
  \fi}
\def\current@color{Black}
\def\Ginclude@eps#1{%
 \message{<#1>}%
  \bgroup
  \def\@tempa{!}%
  \dimen@=10\Gin@req@width
  \dimen@ii1bp%
  \divide\dimen@\dimen@ii
  \@tempdima=10\Gin@req@height
  \divide\@tempdima\dimen@ii
    \special{PSfile="#1"\space
      llx=\strip@pt\Gin@llx\space
      lly=\strip@pt\Gin@lly\space
      urx=\strip@pt\Gin@urx\space
      ury=\strip@pt\Gin@ury\space
      \ifx\Gin@scalex\@tempa\else rwi=\number\dimen@\space\fi
      \ifx\Gin@scaley\@tempa\else rhi=\number\@tempdima\space\fi
      \ifGin@clip clip\fi}%
  \egroup}
\def\Ginclude@bmp#1{%
  \message{<#1>}%
  \dimen@\Gin@req@height
  \advance\dimen@ by-\Gin@lly
  \kern-\Gin@llx\raise\Gin@req@height\hbox{%
   \ifdim\Gin@urx=\z@
     \ifdim\Gin@ury=\z@
        \special{em: graph #1}%
     \else
        \special{em: graph #1,\the\Gin@urx}%
     \fi
  \else
        \special{em: graph #1,\the\Gin@urx,\the\Gin@ury}%
  \fi
 }%
}
\def\Grot@start{%
 \special{ps: gsave currentpoint
 currentpoint translate \Grot@angle\space neg
 rotate neg exch neg exch translate}}
\def\Grot@end{\special{ps: currentpoint grestore moveto}}
\def\Gscale@start{\special{ps:  currentpoint currentpoint translate
  \Gscale@x\space \Gscale@y\space scale neg exch neg exch translate}}
\def\Gscale@end{\special{ps:  currentpoint currentpoint translate
  1 \Gscale@x\space div 1 \Gscale@y\space div scale
  neg exch neg exch translate}}
\def\color@arg#1{%
  \dimen@#1\p@
  \ifdim\dimen@<\z@\out@of@range
  \else\ifdim\dimen@>\p@\out@of@range
  \fi\fi}
\def\color@rgb#1{\color@@rgb#1\@@}
\def\color@@rgb#1,#2,#3\@@{%
  \color@arg{#1}%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@rgb@{ #1 #2 #3}}
\def\color@cmyk#1{\color@@cmyk#1\@@}
\def\color@@cmyk#1,#2,#3,#4\@@{%
  \color@arg{#1}%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \color@cmyk@{#1 #2 #3 #4}}
\def\definecolor@gray#1#2{%
  \color@arg{#2}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@gray@{#2}}}
\def\definecolor@rgb#1#2{\definecolor@rgb@{#1}#2\@@}
\def\definecolor@rgb@#1#2,#3,#4\@@{%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@rgb@{#2 #3 #4}}}
\def\definecolor@cmyk#1#2{\definecolor@cmyk@{#1}#2\@@}
\def\definecolor@cmyk@#1#2,#3,#4,#5\@@{%
  \color@arg{#2}%
  \color@arg{#3}%
  \color@arg{#4}%
  \color@arg{#5}%
  \expandafter\def\csname\string\color @#1\endcsname{%
                          \color@cmyk@{#2 #3 #4 #5}}}
\def\Gin@extensions{eps,ps,eps.gz,ps.gz,eps.Z}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@ps}#1{{eps}{ps}{#1}}
\@namedef{Gin@rule@eps}#1{{eps}{eps}{#1}}
\@namedef{Gin@rule@pz}#1{{eps}{bb}{`gunzip -c #1}}
\@namedef{Gin@rule@eps.Z}#1{{eps}{eps.bb}{`gunzip -c #1}}
\@namedef{Gin@rule@ps.Z}#1{{eps}{ps.bb}{`gunzip -c #1}}
\@namedef{Gin@rule@ps.gz}#1{{eps}{ps.bb}{`gunzip -c #1}}
\@namedef{Gin@rule@eps.gz}#1{{eps}{eps.bb}{`gunzip -c #1}}
\@namedef{Gin@rule@pcx}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@msp}#1{{bmp}{}{#1}}
\endinput
%% 
%% End of file `dvips.def'.
