%% 
%% This is file `emtex.def', generated on <1994/7/28> 
%% with the docstrip utility (2.2h).
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `emtex,dosrules')
%% 
%% IMPORTANT NOTICE:
%% You are not allowed to distribute this file.
%% For distribution of the original source see
%% the copyright notice in the file drivers.dtx .
%% 
%% drivers.dtx Copyright (C) 1994 David Carlisle Sebastian Rahtz
\ProvidesFile{emtex.def}
        [1994/06/08 v1.6 Driver-dependant file (DPC,SPQR)]
\expandafter\ifx\csname ver@emtex.def\endcsname\relax\endinput\fi
\def\Ginclude@bmp#1{%
  \raise\Gin@req@height\hbox{\special{em:graph #1}}%
\typeout{WARNING: emtex does not permit graphics to be scaled}%
}
\def\Gin@extensions{eps,ps,pcx,bmp}
\def\Gin@sepdefault{.}%
\@namedef{Gin@rule@pcx}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@msp}#1{{bmp}{}{#1}}
\endinput
%% 
%% End of file `emtex.def'.
